/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.Destination;
import javax.jms.Message;
import javax.jms.Session;

import org.junit.Ignore;
import org.junit.Test;

import client.TestConfiguration;

/**
 * Client for BJM_3003_TestCase
 *
 * If the value of the @correlationScheme attribute is "sca:messageID" the SCA runtime
 * MUST set the correlation ID of replies to the message ID of the corresponding request 
 * 
 * This test uses the JMS test runner to send a JMS message to the test composite's service.
 */
public class BJM_3003_TestCase extends BaseJMSTestRunner {

    private String requestMessageID;

    protected TestConfiguration getTestConfiguration() {
    	JMSTestConfiguration config = new JMSTestConfiguration();
    	config.testName          = this.getClass().getSimpleName().substring(0, 8);
    	config.input             = "BJM_3003 request message";
    	config.output[0]         = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><return>service1 operation1 invoked with BJM_3003 request message</return>";
    	config.composite         = "Test_" + config.testName + ".composite";
    	config.contributionNames = new String[] { "BJM_3003", "BJM_General", "BJM_General" + _Lang };
        config.destinationName   = "TEST_BJM_3003_Queue";

    	return config;
    }
    
    /**
     * Send the request message.  Retrieve the message ID that was in the request message.
     *
     * @param sess - the JMS session
     * @param dest - the JMS destination
     * @param message - the JMS message
     *
     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
     */
    public void sendRequestMessage( Session sess, Destination dest, Message request ) throws Exception {
        super.sendRequestMessage(sess,dest,request);
        requestMessageID = request.getJMSMessageID();
    }

    /**
     * Check the reply message.
     *
     * @param reply - the reply message
     * @return the output.
     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
     */
    public String checkReplyMessage( Message reply ) throws Exception {
        String output;
        String correlId = reply.getJMSCorrelationID();
        if( correlId.equals(requestMessageID) )
            output = super.checkReplyMessage(reply);
        else 
            output = "Reply Correlation ID: "+correlId+" does not match request Message ID: "+requestMessageID;

        return output;
    }

    /**
     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
     */
    @Ignore
    @Test
    public void testFoo() throws Exception {  	
    }
    
} // end class BJM_3003_TestCase