/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.Message;
import javax.jms.Session;
import javax.jms.TextMessage;

import org.junit.Ignore;
import org.junit.Test;

import client.TestConfiguration;

/**
 * Client for BJM_4011_TestCase
 * 
 * When a message is received at an SCA service with JMS binding and the resolved
 * operation name is not in the target component's interface the SCA runtime MUST raise
 * an error
 * 
 */
public class BJM_4011_TestCase extends BaseJMSTestRunner {
	
	   protected TestConfiguration getTestConfiguration() {
	    	JMSTestConfiguration config = new JMSTestConfiguration();
	    	config.testName          = this.getClass().getSimpleName().substring(0, 8);
	    	config.input             = "BJM_4011 request message";
	    	config.output[0]         = "exception";
	    	config.composite         = "Test_" + config.testName + ".composite";
	    	config.contributionNames = new String[] { "BJM_4011", "BJM_General", "BJM_General" + _Lang };
	        config.destinationName   = "TEST_BJM_4011_Queue";
	 
	    	return config;
	    }

	   
	    /**
	     * Create the request message.
	     * @param input - input string
	     * @param sess - the JMS session
	     * @return the request message.
	     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
	     */
	    public Message createRequestMessage( String input, Session sess ) throws Exception {
	    	TextMessage textMsg = (TextMessage)super.createRequestMessage(input, sess);
	        textMsg.setText("<?xml version=\"1.0\" encoding=\"UTF-8\"?><operation3>"+input+"</operation3>");
	        return textMsg;
	    }
	    
	    /**
	     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
	     */
	    @Ignore
	    @Test
	    public void testFoo() throws Exception {  	
	    }
}  // end class BJM_4011_TestCase
