/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.Message;

import org.junit.Ignore;
import org.junit.Test;

import client.TestConfiguration;


/**
 * Client for BJM_3025_1_TestCase
 * 
 * When sending messages for a JMS binding, the SCA runtime MUST set each named
 * user property with type and value specified in the binding definition in the following
 * priority order:
 * 1) the type and value for the named user property specified in an
 * operationProperties/headers/property element matching the name of the operation
 * being invoked (highest priority);
 * 2) the type and value for the named user property specified in a headers/property
 * element (lowest priority)
 * 
 * This is the operationProperties case
 * 
 */
public class BJM_3025_1_TestCase extends BaseJMSTestRunner {

    protected TestConfiguration getTestConfiguration() {
    	JMSTestConfiguration config = new JMSTestConfiguration();
    	config.testName          = this.getClass().getSimpleName().substring(0, 10);
    	config.input             = "BJM_3025 request message";
    	config.output[0]         = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><arg0>service1 operation1 invoked with BJM_3025 request message</arg0>";
    	config.composite         = "Test_" + config.testName + ".composite";
    	config.contributionNames = new String[] { "BJM_3025_1", "BJM_General", "BJM_General" + _Lang };
        config.destinationName   = "TEST_BJM_3025_Queue";
        config.replyDestinationName   = "TEST_BJM_3025_REF_Queue";

    	return config;
    }
    
    /**
     * Check the reply message.
     *
     * @param reply - the reply message
     * @return the output.
     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
     */
    public String checkReplyMessage( Message reply ) throws Exception {
        String output;

        // There are properties of type: boolean, byte, short, int, long, float, double, and String
        // Get each property as an Object property and cast to a specific type to ensure that the
        // user property was actually set as the correct type in the message.
        // Using getBooleanProperty etc. will result in automatic conversion and not test this correctly.
        try {
            boolean booleanProp = ((Boolean)reply.getObjectProperty("UserBoolean")).booleanValue();
            byte byteProp = ((Byte)reply.getObjectProperty("UserByte")).byteValue();
            short shortProp = ((Short)reply.getObjectProperty("UserShort")).shortValue();
            int intProp = ((Integer)reply.getObjectProperty("UserInt")).intValue();
            long longProp = ((Long)reply.getObjectProperty("UserLong")).longValue();
            float floatProp = ((Float)reply.getObjectProperty("UserFloat")).floatValue();
            double doubleProp = ((Double)reply.getObjectProperty("UserDouble")).doubleValue();
            String string1Prop = ((String)reply.getObjectProperty("UserString1"));
            String string2Prop = ((String)reply.getObjectProperty("UserString2"));
            String source = ((String)reply.getObjectProperty("Source"));

            if( "operationProperties".equals(source) &&
                booleanProp == true &&
                byteProp == -57 &&
                shortProp == 1024 &&
                intProp == 1234567 &&
                longProp == 1234567891234L &&
                floatProp == 3.14159F &&
                doubleProp == 3.14159 &&
                "OPString1".equals(string1Prop) &&
                "OPString2".equals(string2Prop) )
                output = super.checkReplyMessage(reply);
            else 
                output = "Reply message has properties: " +
                         " 'Source'='" + source + 
                         "', 'UserBoolean'='" + booleanProp +
                         "', 'UserByte'='" + byteProp +
                         "', 'UserShort'=' " + shortProp +
                         "', 'UserInt'='" + intProp +
                         "', 'UserLong'='" + longProp +
                         "', 'UserFloat'='" + floatProp +
                         "', 'UserDouble'='" + doubleProp +
                         "', 'UserString1'='" + string1Prop +
                         "', 'UserString2'='" + string2Prop + "'.";

        } catch( ClassCastException exc ) {
            output = "User property of incorrect type: "+exc.getMessage();
        }
          
        return output;
    }
    
    /**
     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
     */
    @Ignore
    @Test
    public void testFoo() throws Exception {  	
    }
    
} // end class BJM_3025_1_TestCase
