/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.Destination;
import javax.jms.Message;
import javax.jms.Session;
import javax.jms.TextMessage;

import org.junit.Ignore;
import org.junit.Test;

import client.TestConfiguration;

/**
 * Client for BJM_3026_1_TestCase
 * 
 * When receiving messages for a JMS binding, the SCA runtime MUST use a message
 * selector if specified in the binding definition in the following priority order:
 * 1) the value for the message selector specified in the @uri attribute value's "selector"
 *    parameter (highest priority);
 * 2) the value for the message selector specified in the messageSelection/@selector
 *    attribute;
 * 3) otherwise no message selector is used (lowest priority) 
 * 
 * This is the @uri case
 */
public class BJM_3026_1_TestCase extends BaseJMSTestRunner {


    protected TestConfiguration getTestConfiguration() {    	
        JMSTestConfiguration config = new JMSTestConfiguration();
	config.testName          = this.getClass().getSimpleName().substring(0, 10);
	config.input             = "BJM_3026 request message";
	config.output[0]         = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><return>service1 operation1 invoked with BJM_3026 type1 message</return>";
	config.composite         = "Test_" + config.testName + ".composite";
	config.contributionNames = new String[] { "BJM_3026_1", "BJM_General", "BJM_General" + _Lang };
	config.destinationName   = "TEST_BJM_3026_Queue";

	return config;
	}
    
    /**
     * Send the request message.  Retrieve the message ID that was in the request message.
     *
     * @param sess - the JMS session
     * @param dest - the JMS destination
     * @param message - the JMS message
     *
     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
     */
    public void sendRequestMessage( Session sess, Destination dest, Message request ) throws Exception {
    	TextMessage tm = (TextMessage)request;
    	
    	request.setJMSType("typeX");
    	super.sendRequestMessage(sess,dest,request);

    	tm.setText(tm.getText().replace("BJM_3026 request message", "BJM_3026 type1 message"));
    	request.setJMSType("type1");
    	super.sendRequestMessage(sess,dest,request);

    	// hold the session and destination so the other message can be deleted
    	this.sess = sess;
    	this.dest = dest;
    	
    }
    private Session sess;
    private Destination dest;

    public String checkReplyMessage( Message reply ) throws Exception {
        String output = super.checkReplyMessage(reply);
        
        Message msg = sess.createConsumer(dest).receive();
        if ("typeX".equals(msg.getJMSType())) {
            return output;
        } else {
            return "unexpected type on unreceived message: " + msg.getJMSType();
        }
    }
    
    /**
     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
     */
    @Ignore
    @Test
    public void testFoo() throws Exception {  	
    }
    
} // end class BJM_3026_1_TestCase
