/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.JMSException;
import javax.jms.Message;

import org.junit.Ignore;
import org.junit.Test;

import client.TestConfiguration;

/**
 * Client for BJM_4003_TestCase
 * 
 * When using the default wire format to send request messages, if there is a single
 * parameter and the interface includes more than one operation, the SCA runtime MUST
 * set the JMS user property "scaOperationName" to the name of the operation being
 * invoked
 * 
 * Tests if the JMS user property "scaOperationName"  is set to the name of the operation being invoked
 * when using the default wire format to send request messages, 
 * and there is a single parameter and the interface includes more than one operation
 */

public class BJM_4003_TestCase extends BaseJMSTestRunner{
	

    protected TestConfiguration getTestConfiguration() {
	    	JMSTestConfiguration config = new JMSTestConfiguration();
	    	config.testName          = this.getClass().getSimpleName().substring(0, 8);
	    	config.input             = "BJM_4003 request message";
	    	config.output[0]         = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><return>Service2Impl2.operation1 service1 operation1 invoked with BJM_4003 request message</return>";
	    	config.composite         = "Test_" + config.testName + ".composite";
	    	config.contributionNames = new String[] { "BJM_4003", "BJM_General", "BJM_General" + _Lang };
	        config.destinationName   = "TEST_BJM_4003_Queue";
	        config.mockServiceDestinationName = "TEST_BJM_4003_Service_Queue";
	 
	    	return config;
	    }
	
    private String scaOperationName;

    @Override
    protected void checkServiceRequest(Message m) throws JMSException {
       scaOperationName = m.getStringProperty("scaOperationName");
    }
    
    @Override
    public String checkReplyMessage( Message reply ) throws Exception {
        if ("operation1".equals(scaOperationName)) {
            return super.checkReplyMessage(reply);
        }
        return "scaOperationName not correctly set: " + scaOperationName;
    }

	    /**
	     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
	     */
	    @Ignore
	    @Test
	    public void testFoo() throws Exception {  	
	    }
}  // end class BJM_4003_TestCase
