/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.BytesMessage;
import javax.jms.Message;
import javax.jms.Session;
import javax.jms.TextMessage;

import org.junit.Ignore;
import org.junit.Test;

import testClient.TestInvocation;
import client.TestConfiguration;

/**
 * Client for BJM_4006_TestCase
 * 
 * When using the default wire format an SCA runtime MUST send either a JMS text or a
 * JMS bytes message
 * 
 */
public class BJM_4006_TestCase extends NamedReplyJMSTestRunner {

    protected TestConfiguration getTestConfiguration() {
    	NamedReplyJMSTestConfiguration config = new NamedReplyJMSTestConfiguration();
    	config.testName 		 = this.getClass().getSimpleName().substring(0, 8);
    	config.input 		 	 = "request";
    	config.output[0] 		 = "Reply message is BytesMessage or TextMessage";
    	config.composite 		 = "Test_" + config.testName + ".composite";
    	config.testServiceName 	 = "TestClient";
    	config.contributionNames = new String[] { "BJM_4006", "BJM_General", "BJM_General" + _Lang };
    	config.serviceInterface  = TestInvocation.class;
        config.destinationName   = "TEST_BJM_4006_Service_Queue";
        config.calloutDestinationName = "TEST_BJM_4006_Reference_Queue";
    	return config;
    }
	   
    /**
     * Create the request message.
     * @param input - input string
     * @param sess - the JMS session
     * @return the request message.
     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
     */
    public Message createRequestMessage( String input, Session sess ) throws Exception {
        TextMessage textMsg = sess.createTextMessage();
        textMsg.setText("<?xml version=\"1.0\" encoding=\"UTF-8\"?><operation1>"+input+"</operation1>");

        return textMsg;
    }
   
    /**
     * Check the reply message.
     *
     * @param reply - the reply message
     * @return the output.
     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
     */
    public String checkReplyMessage( Message reply ) throws Exception {
        String output;
        if (reply instanceof BytesMessage || reply instanceof TextMessage) {
            output = "Reply message is BytesMessage or TextMessage";
        } else {
            output = super.checkReplyMessage(reply);
        }

        return output;
    }

    /**
     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
     */
    @Ignore
    @Test
    public void testFoo() throws Exception {  	
    }
}  // End class BJM_4006_TestCase
