/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.Message;
import javax.jms.Session;

import org.junit.Ignore;
import org.junit.Test;

import client.TestConfiguration;

/**
 * Client for BJM_4008_TestCase
 *
 * When a binding.jms element specifies the operationSelector.jmsDefault element, the
 * SCA runtime MUST use the default operation selection algorithm to determine the
 * selected operation
 * 
 */
public class BJM_4008_TestCase extends BaseJMSTestRunner   {
	
	   protected TestConfiguration getTestConfiguration() {
	    	JMSTestConfiguration config = new JMSTestConfiguration();
	    	config.testName          = this.getClass().getSimpleName().substring(0, 8);
	    	config.input             = "BJM_4008 request message";
	    	config.output[0]         = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><return>service2 operation2 invoked with BJM_4008 request message</return>";
	    	config.composite         = "Test_" + config.testName + ".composite";
	    	config.contributionNames = new String[] { "BJM_4008", "BJM_General", "BJM_General" + _Lang };
	        config.destinationName   = "TEST_BJM_4008_Queue";
	 
	    	return config;
	    }
	   
	    /**
	     * Create the request message.
	     * @param input - input string
	     * @param sess - the JMS session
	     * @return the request message.
	     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
	     */
	    public Message createRequestMessage( String input, Session sess ) throws Exception {
	    	Message message = super.createRequestMessage(input, sess);
	        message.setStringProperty("scaOperationName", "operation2");
	        return message;
	    }
	   
	    /**
	     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
	     */
	    @Ignore
	    @Test
	    public void testFoo() throws Exception {  	
	    }

}  // end class BJM_4008_TestCase
