/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.Destination;
import javax.jms.Message;
import javax.jms.Session;
import javax.jms.TextMessage;

import client.TestConfiguration;

/**
 * Client for BJM_6007_TestCase
 * 
 * For an SCA service with a JMS binding, when a response message is sent as part of a
 * request/response MEP where the request message included a non-null JMSReplyTo
 * destination, the SCA runtime MUST send the response message to that destination
 *  
 * 
 */
public class BJM_6007_TestCase extends NamedReplyJMSTestRunner {
	
	   protected TestConfiguration getTestConfiguration() {
	    	NamedReplyJMSTestConfiguration config = new NamedReplyJMSTestConfiguration();
	    	config.testName          = this.getClass().getSimpleName().substring(0, 8);
	    	config.input             = "BJM_6007 request message";
	    	config.output[0]         = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><return>service1 operation1 invoked with BJM_6007 request message</return>";
	    	config.composite         = "Test_" + config.testName + ".composite";
	    	config.contributionNames = new String[] { "BJM_6007", "BJM_General", "BJM_General" + _Lang };
	        config.destinationName   = "TEST_BJM_6007_Queue";
	        config.calloutDestinationName = "TEST_BJM_6007_Receive_Queue";
	 
	    	return config;
	    }
	   
	    /**
	     * Create the request message.
	     * @param input - input string
	     * @param sess - the JMS session
	     * @return the request message.
	     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
	     */
	    public Message createRequestMessage( String input, Session sess) throws Exception {
	        Destination replyQueue = sess.createQueue("TEST_BJM_6007_Receive_Queue");
	        TextMessage textMsg = sess.createTextMessage();
	        textMsg.setJMSReplyTo(replyQueue);
	        textMsg.setText("<?xml version=\"1.0\" encoding=\"UTF-8\"?><operation1>"+input+"</operation1>");

	        return textMsg;
	    }
} //  End class BJM_6007_TestCase
