/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageProducer;
import javax.jms.Session;
import javax.jms.TextMessage;

import org.junit.Ignore;
import org.junit.Test;

import testClient.TestInvocation;
import client.TestConfiguration;

/**
 * Client for BJM_6017_TestCase
 * 
 * For an SCA service with a JMS binding, when a callback request message is sent the
 * SCA runtime MUST set the JMSReplyTo destination in the callback request message
 * as defined in sections 6.1 or 6.2 as appropriate for the type of the callback operation
 * invoked
 *  
 *  This is the section 6.1 oneway callback case so no replyTo should be set
 *  
 */
public class BJM_6017_2_TestCase extends NamedReplyJMSTestRunner {

	private Session sess;

	protected TestConfiguration getTestConfiguration() {
    	NamedReplyJMSTestConfiguration config = new NamedReplyJMSTestConfiguration();
    	config.testName 		 = this.getClass().getSimpleName().substring(0, 8);
    	config.input 		 	 = "request";
    	config.output[0] 		 = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><arg0>operation1 callback request</arg0>";
    	config.composite 		 = "Test_" + config.testName + ".composite";
    	config.testServiceName 	 = "TestClient";
    	config.contributionNames = new String[] { "BJM_6017", "BJM_General", "BJM_General" + _Lang };
    	config.serviceInterface  = TestInvocation.class;
        config.destinationName   = "TEST_BJM_6017_Service_Queue";
        config.calloutDestinationName = "TEST_BJM_6017_CB_Binding_Queue";
    	return config;
    }

	@Override
    public Message createRequestMessage( String input, Session sess ) throws Exception {
		this.sess = sess;
    	TextMessage msg = (TextMessage) super.createRequestMessage(input, sess);
//    	msg.setText(msg.getText().replace("operation1", "onewayOperation1"));
//    	msg.setJMSReplyTo(null); // clear replyTo so the binding defn is used
    	msg.setStringProperty("scaCallbackDestination", "jms:jndi:TEST_BJM_6017_CB_Binding_Queue");
    	return msg;
    }
	
    public String checkReplyMessage( Message reply ) throws Exception {
        // the callback request message should not have a replyTo set
    	if (reply.getJMSReplyTo() != null) {
    		return "callback message has replyTo"; 
    	}
//    	sendCBReply(reply);
    	return super.checkReplyMessage(reply);
    }

    /**
     * Send a null reply to stop the callback sender hanging waiting for a reply
     * @throws JMSException 
     */
    private void sendCBReply(Message reply) throws JMSException {
    	TextMessage msg = sess.createTextMessage();
    	msg.setJMSCorrelationID(reply.getJMSMessageID());
    	MessageProducer p = sess.createProducer(reply.getJMSReplyTo());
    	p.send(msg);
    	p.close();
	}

	/**
     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
     */
    @Ignore
    @Test
    public void testFoo() throws Exception {  	
    }
}  // end class BJM_6017_2_TestCase
